@@ -162,7 +162,7 @@ class VaspToApiXmlSchema(object):
                 band_dir_gap = str(round(vrun.get_dir_gap, 2))
             except Exception:
                 print("Cannot get bandgap.", kp)
-
+                pass
             line += "<band_indir_gap>" + band_indir_gap + "</band_indir_gap>"
             line += "<band_dir_gap>" + band_dir_gap + "</band_dir_gap>"
 
@@ -319,66 +319,72 @@ class VaspToApiXmlSchema(object):
         """Get electronic dos information with , _ and ; seperators."""
         line = ""
         try:
-            total_dos = vrun.total_dos
-            # energies = np.array(total_dos[0])
-            spdf_dos = vrun.get_spdf_dos()
-            atom_dos = vrun.get_atom_resolved_dos()
+            try:
+                line = ""
+                total_dos = vrun.total_dos
+                for i, ii in enumerate(total_dos):
+                    if i == 0:
+                        line = (
+                            line
+                            + "<edos_energies>'"
+                            + ",".join(map(str, np.array(ii) - vrun.efermi))
+                            + "'</edos_energies>"
+                        )
+                    elif i == 1:
+                        line += (
+                            "<total_edos_up>'"
+                            + ",".join(map(str, ii))
+                            + "'</total_edos_up>"
+                        )
+                    elif i == 2:
+                        line += (
+                            "<total_edos_down>'"
+                            + ",".join(map(str, ii))
+                            + "'</total_edos_down>"
+                        )
+                # energies = np.array(total_dos[0])
+            except Exception as exp:
+                print("No total dos", exp)
+                pass
+            try:
+                spdf_dos = vrun.get_spdf_dos()
+                atom_dos = vrun.get_atom_resolved_dos()
 
-            line = ""
-            for i, ii in enumerate(total_dos):
-                if i == 0:
-                    line = (
-                        line
-                        + "<edos_energies>'"
-                        + ",".join(map(str, np.array(ii) - vrun.efermi))
-                        + "'</edos_energies>"
-                    )
-                elif i == 1:
+                line += "<spdf_dos>"
+                for i, j in spdf_dos.items():
                     line += (
-                        "<total_edos_up>'"
-                        + ",".join(map(str, ii))
-                        + "'</total_edos_up>"
-                    )
-                elif i == 2:
-                    line += (
-                        "<total_edos_down>'"
-                        + ",".join(map(str, ii))
-                        + "'</total_edos_down>"
+                        "<"
+                        + str(i)
+                        + ">"
+                        # + ">'"
+                        + "'"
+                        + ",".join(map(str, j))
+                        + "'"
+                        + "</"
+                        # + "'</"
+                        + str(i)
+                        + ">"
                     )
 
-            line += "<spdf_dos>"
-            for i, j in spdf_dos.items():
-                line += (
-                    "<"
-                    + str(i)
-                    + ">"
-                    # + ">'"
-                    + "'"
-                    + ",".join(map(str, j))
-                    + "'"
-                    + "</"
-                    # + "'</"
-                    + str(i)
-                    + ">"
-                )
-
-            line += "</spdf_dos>"
-            line += "<elemental_dos>"
-            spin_up_info = atom_dos["spin_up_info"]
-            spin_down_info = atom_dos["spin_down_info"]
-            line += '<spin_up_info>"'
-            for i, j in spin_up_info.items():
-                line += str(i) + str("_") + ",".join(map(str, j)) + ";"
-            line += '"</spin_up_info>'
-
-            line += '<spin_down_info>"'
-            # line += '<spin_down_info>"'
-            for i, j in spin_down_info.items():
-                line += str(i) + str("_") + ",".join(map(str, j)) + ";"
-            line += '"</spin_down_info>'
-            # line += '"</spin_down_info>'
-            line += "</elemental_dos>"
+                line += "</spdf_dos>"
+                line += "<elemental_dos>"
+                spin_up_info = atom_dos["spin_up_info"]
+                spin_down_info = atom_dos["spin_down_info"]
+                line += '<spin_up_info>"'
+                for i, j in spin_up_info.items():
+                    line += str(i) + str("_") + ",".join(map(str, j)) + ";"
+                line += '"</spin_up_info>'
 
+                line += '<spin_down_info>"'
+                # line += '<spin_down_info>"'
+                for i, j in spin_down_info.items():
+                    line += str(i) + str("_") + ",".join(map(str, j)) + ";"
+                line += '"</spin_down_info>'
+                # line += '"</spin_down_info>'
+                line += "</elemental_dos>"
+            except Exception as exp:
+                print("No spdf dos", exp)
+                pass
             fermi_velocities = ""
             try:
                 fermi_velocities = ",".join(map(str, vrun.fermi_velocities[0]))
@@ -393,6 +399,7 @@ class VaspToApiXmlSchema(object):
 
         except Exception as exp:
             print("Cannot get DOS data", vrun, exp)
+            pass
         return line
 
     def get_xrd(self, atoms):
@@ -411,8 +418,8 @@ class VaspToApiXmlSchema(object):
                 + array_to_string(intensities)
                 + '"</intensities>'
             )
-        except Exception:
-            print("Cannot gt XRD pattern.")
+        except Exception as exp:
+            print("Cannot gt XRD pattern.", exp)
             pass
         return line
 
@@ -435,8 +442,8 @@ class VaspToApiXmlSchema(object):
                 data = self.electronic_band_struct(
                     vasprun=vrun, kpoints_file_path=kp
                 )
-            except Exception:
-                print("Cannot get ebands info", folder)
+            except Exception as exp:
+                print("Cannot get ebands info", folder, exp)
                 pass
         os.chdir(folder)
         info["main_bands_info"] = data
@@ -456,8 +463,8 @@ class VaspToApiXmlSchema(object):
                 data = self.electronic_band_struct(
                     vasprun=vrun, kpoints_file_path=kp
                 )
-            except Exception:
-                print("Cannot get hseband info", folder)
+            except Exception as exp:
+                print("Cannot get hseband info", folder, exp)
                 pass
         os.chdir(folder)
         info["main_hse_bands_info"] = data
@@ -477,8 +484,8 @@ class VaspToApiXmlSchema(object):
                 data = self.electronic_band_struct(
                     vasprun=vrun, kpoints_file_path=kp
                 )
-            except Exception:
-                print("Cannot get ebands info", folder)
+            except Exception as exp:
+                print("Cannot get ebands info", folder, exp)
                 pass
         os.chdir(folder)
         info["main_pbe0_bands_info"] = data
@@ -702,8 +709,8 @@ class VaspToApiXmlSchema(object):
                         line += (
                             jid + "_" + atom + "_" + str(round(Ef, 3)) + ","
                         )
-        except Exception:
-            print("Cannot get vacancy info.", folder)
+        except Exception as exp:
+            print("Cannot get vacancy info.", folder, exp)
             pass
         info["vacancy_formation_energy"] = line
         os.chdir(folder)
@@ -740,7 +747,8 @@ class VaspToApiXmlSchema(object):
                     reals[:, 6][0],
                 )
                 lopt = str(round(max_linopt_eps, 2))
-            except Exception:
+            except Exception as exp:
+                print("Error in dielectric_loptics", exp)
                 pass
 
             line += "<max_linopt_eps>" + lopt + "</max_linopt_eps>"
@@ -749,8 +757,8 @@ class VaspToApiXmlSchema(object):
                 fermi_velocities = ",".join(
                     map(str, lvrun.fermi_velocities[0])
                 )
-            except Exception:
-                print("Cannot get the lepsilon Fermi-velocity.", vrun)
+            except Exception as exp:
+                print("Cannot get the lepsilon Fermi-velocity.", vrun, exp)
                 pass
             line += (
                 '<fermi_velocities>"'
@@ -776,8 +784,8 @@ class VaspToApiXmlSchema(object):
                     + str(i)
                     + ">"
                 )
-        except Exception:
-            print("Cannot get loptics data", vrun)
+        except Exception as exp:
+            print("Cannot get loptics data", vrun, exp)
             pass
         eff_slme = ""
         eff_sq = ""
@@ -795,8 +803,8 @@ class VaspToApiXmlSchema(object):
             eff_sq = SolarEfficiency().calculate_SQ(indirgap)
             eff_slme = round(100 * eff_slme, 2)
             eff_sq = round(100 * eff_sq, 2)
-        except Exception:
-            print("Cannot get solar data.")
+        except Exception as exp:
+            print("Cannot get solar data.", exp)
             pass
         line += "<solar_slme>" + str(eff_slme) + "</solar_slme>"
         line += "<solar_sq>" + str(eff_sq) + "</solar_sq>"
@@ -817,8 +825,8 @@ class VaspToApiXmlSchema(object):
                 folder = i.split(".json")[0]
                 vrun = os.getcwd() + "/" + folder + "/vasprun.xml"
                 data = self.loptics_optoelectronics(vrun)
-            except Exception:
-                print("Cannot get semilocal optics data", folder)
+            except Exception as exp:
+                print("Cannot get semilocal optics data", folder, exp)
                 pass
         os.chdir(folder)
         info["main_optics_info"] = data
@@ -836,8 +844,8 @@ class VaspToApiXmlSchema(object):
                 folder = i.split(".json")[0]
                 vrun = os.getcwd() + "/" + folder + "/vasprun.xml"
                 data = self.loptics_optoelectronics(vrun)
-            except Exception:
-                print("Cannot get mbj optics data", folder)
+            except Exception as exp:
+                print("Cannot get mbj optics data", folder, exp)
                 pass
         os.chdir(folder)
         info["main_optics_mbj_info"] = data
@@ -898,8 +906,8 @@ class VaspToApiXmlSchema(object):
             )
             max_spillage = round(max(sp["spillage_k"]), 3)
             line += "<max_spillage>" + str(max_spillage) + "</max_spillage>"
-        except Exception:
-            print("Cannot get spillage info", soc_wf, nonsoc_wf)
+        except Exception as exp:
+            print("Cannot get spillage info", soc_wf, nonsoc_wf, exp)
             pass
         return line
 
@@ -922,8 +930,8 @@ class VaspToApiXmlSchema(object):
                 data = self.spillage(
                     soc_wf=soc_wf, nonsoc_wf=nonsoc_wf, jid=jid
                 )
-            except Exception:
-                print("Cannot get spillage info", folder)
+            except Exception as exp:
+                print("Cannot get spillage info", folder, exp)
                 pass
         os.chdir(folder)
         info["main_spillage_info"] = data
@@ -1903,6 +1911,10 @@ class VaspToApiXmlSchema(object):
 
 
 """
+folder = '/rk2/knc6/JARVIS-DFT/2DRar-bulk/mp-17173_PBEBO'
+filename='/users/knc6/Software/Devs/jarvis/jarvis/db/p.xml'
+VaspToApiXmlSchema(folder=folder).write_xml(filename=filename)
+
 folder = "/rk2/knc6/JARVIS-DFT/Met-Rar/mp-10891_PBEBO"
 filename = "/cluster/users/knc6/justback/MTI/JVASP-16366.xml"
 VaspToApiXmlSchema(folder=folder).write_xml(filename=filename)
